@@ -1,3 +1,4 @@
+# Initialize the l'Ecuyer random number generator ####
 #' @title Initialize the l'Ecuyer random number generator
 #'
 #' @description See the documentation for the parallel package
@@ -14,9 +15,13 @@
 # @examples
 init.lecuyerRNG <- function(seed = 1, stream = 2){
 
+  # Set RNGversion
+  suppressMessages(RNGversion("3.5.0"))
+  
   # Set the random number generator
   RNGkind("L'Ecuyer-CMRG")
-
+  
+  
   # Set the seed
   set.seed(seed)
 
@@ -32,7 +37,8 @@ init.lecuyerRNG <- function(seed = 1, stream = 2){
 
 }
 
-#' Simulate an MRMC data set
+# Simulate an MRMC data set ####
+#' Simulate an MRMC data set ####
 #'
 #' @description
 #' This program simulates observations from one set of readers scoring one set of cases.
@@ -75,13 +81,13 @@ init.lecuyerRNG <- function(seed = 1, stream = 2){
 #'
 #' @export
 #'
-#' @examples
-#' # Create a sample configuration object
-#' config <- sim.gRoeMetz.config()
-#' # Simulate an MRMC ROC data set
-#' dFrame.imrmc <- sim.gRoeMetz(config)
-#' # Analyze the MRMC ROC data
-#' result <- doIMRMC(dFrame.imrmc)
+# @examples
+# # Create a sample configuration object
+# config <- sim.gRoeMetz.config()
+# # Simulate an MRMC ROC data set
+# dFrame.imrmc <- sim.gRoeMetz(config)
+# # Analyze the MRMC ROC data
+# result <- doIMRMC(dFrame.imrmc)
 
 simMRMC <- function(simMRMC.config) {
 
@@ -127,65 +133,7 @@ simMRMC <- function(simMRMC.config) {
 
 }
 
-#' Convert an MRMC data frame to a score matrix
-#'
-#' @description Convert an MRMC data frame to a score matrix, dropping readers or cases with no observations
-#'
-#' @param dfMRMC An MRMC data frame
-#'
-#' @return A matrix [nCases, nReaders] of the scores each reader reported for each case
-#'
-#' @export
-#'
-convertDFtoScoreMatrix <- function(dfMRMC) {
-
-  dfMRMC <- droplevels(dfMRMC)
-
-  caseIDs <- levels(dfMRMC$caseID)
-  readerIDs <- levels(dfMRMC$readerID)
-  nCases <- nlevels(dfMRMC$caseID)
-  nReaders <- nlevels(dfMRMC$readerID)
-
-  scores <- array(-1, c(nCases, nReaders), dimnames = list(caseIDs, readerIDs))
-
-  index <- dfMRMC[ , c("caseID","readerID")]
-  index <- data.matrix(index)
-
-  scores[index] <- dfMRMC$score
-  return(scores)
-
-}
-
-#' Convert an MRMC data frame to a design matrix
-#'
-#' @description Convert an MRMC data frame to a design matrix, dropping readers or cases with no observations
-#'
-#' @param dfMRMC An MRMC data frame
-#'
-#' @return A matrix [nCases, nReaders] indicating which scores were reported for each reader and case
-#'
-#' @export
-#'
-convertDFtoDesignMatrix <- function(dfMRMC) {
-
-  dfMRMC <- droplevels(dfMRMC)
-
-  caseIDs <- levels(dfMRMC$caseID)
-  readerIDs <- levels(dfMRMC$readerID)
-  nCases <- nlevels(dfMRMC$caseID)
-  nReaders <- nlevels(dfMRMC$readerID)
-
-  design <- array(0, c(nCases, nReaders), dimnames = list(caseIDs, readerIDs))
-
-  index <- dfMRMC[ , c("caseID","readerID")]
-  index <- data.matrix(index)
-
-  design[index] <- 1
-
-  return(design)
-
-}
-
+# Simulate an MRMC data set of an ROC experiment comparing two modalities ####
 #' Simulate an MRMC data set of an ROC experiment comparing two modalities
 #'
 #' @description
@@ -275,14 +223,14 @@ convertDFtoDesignMatrix <- function(dfMRMC) {
 #'
 #' @export
 #'
-#' @examples
-#' # Create a sample configuration object
-#' config <- sim.gRoeMetz.config()
-#' # Simulate an MRMC ROC data set
-#' dFrame.imrmc <- sim.gRoeMetz(config)
-#' # Analyze the MRMC ROC data
-#' result <- doIMRMC(dFrame.imrmc)
-#'
+# @examples
+# # Create a sample configuration object
+# config <- sim.gRoeMetz.config()
+# # Simulate an MRMC ROC data set
+# dFrame.imrmc <- sim.gRoeMetz(config)
+# # Analyze the MRMC ROC data
+# result <- doIMRMC(dFrame.imrmc)
+#
 sim.gRoeMetz <- function(config) {
 
   # Unpack modality labels
@@ -417,6 +365,7 @@ sim.gRoeMetz <- function(config) {
 
 }
 
+# Create a configuration object for the sim.gRoeMetz program ####
 #' Create a configuration object for the sim.gRoeMetz program
 #'
 #' @description
@@ -449,13 +398,13 @@ sim.gRoeMetz <- function(config) {
 #'
 #' @export
 #'
-#' @examples
-#' # Create a sample configuration object
-#' config <- sim.gRoeMetz.config()
-#' # Simulate an MRMC ROC data set
-#' dFrame.imrmc <- sim.gRoeMetz(config)
-#' # Analyze the MRMC ROC data
-#' result <- doIMRMC(dFrame.imrmc)
+# @examples
+# # Create a sample configuration object
+# config <- sim.gRoeMetz.config()
+# # Simulate an MRMC ROC data set
+# dFrame.imrmc <- sim.gRoeMetz(config)
+# # Analyze the MRMC ROC data
+# result <- doIMRMC(dFrame.imrmc)
 sim.gRoeMetz.config <- function(
   nR = 5,
   nC.neg = 40,
@@ -524,17 +473,18 @@ sim.gRoeMetz.config <- function(
 
 }
 
+# Simulates a sample MRMC ROC experiment ####
 #' Simulates a sample MRMC ROC experiment
 #'
 #' @return dFrame.imrmc [data.frame] Please refer to the description of the simRoeMetz return variable
 #' @export
 #'
-#' @examples
-#' # Simulate a sample MRMC ROC data set
-#' dFrame.imrmc <- simRoeMetz.example()
-#' # Analyze the MRMC ROC data
-#' result <- doIMRMC(dFrame.imrmc)
-#'
+# @examples
+# # Simulate a sample MRMC ROC data set
+# dFrame.imrmc <- simRoeMetz.example()
+# # Analyze the MRMC ROC data
+# result <- doIMRMC(dFrame.imrmc)
+#
 simRoeMetz.example <- function() {
 
   config <- sim.gRoeMetz.config()
@@ -557,3 +507,70 @@ simRoeMetz.example <- function() {
   return(dFrame.imrmc)
 
 }
+
+## roeMetzConfigs ####
+#' @title roeMetzConfigs
+#' 
+#' @name roeMetzConfigs
+#' 
+#' @description This is a data frame containing the configuration parameters 
+#' used in Roe1997_Acad-Radiol_v4p298. Each row corresponds to one of the twelve configurations
+#' appearing in Table 1 of that paper in a format that can be the input to \code{sim.gRoeMetz}.
+#' 
+#' @details The columns of this data frame are as follows
+#' \itemize{
+#'   \item Experiment labels and size
+#'   \itemize{
+#'     \item modalityID.A: [chr] label modality A
+#'     \item modalityID.B: [chr] label modality B
+#'     \item nR: [num] number of readers
+#'     \item nC.neg: [num] number of signal-absent cases
+#'     \item nC.pos: [num] number of signal-present cases
+#'   }
+#'   \item There are six fixed effects:
+#'   \itemize{
+#'     \item mu.neg: [num] signal-absent (neg, global mean)
+#'     \item mu.pos: [num] signal-present (pos, global mean)
+#'     \item mu.Aneg: [num] modality A signal-absent (Aneg, modality effect)
+#'     \item mu.Bneg: [num] modality B signal-absent (Bneg, modality effect)
+#'     \item mu.Apos: [num] modality A signal-present (Apos, modality effect)
+#'     \item mu.Bpos: [num] modality B signal-present (Bpos, modality effect)
+#'   }
+#'   \item There are six random effects that are independent of modality
+#'   \itemize{
+#'     \item var_r.neg: [num] variance of random reader effect
+#'     \item var_c.neg: [num] variance of random case effect
+#'     \item var_rc.neg: [num] variance of random reader by case effect
+#'     \item var_r.pos: [num] variance of random reader effect
+#'     \item var_c.pos: [num] variance of random case effect
+#'     \item var_rc.pos: [num] variance of random reader by case effect
+#'   }
+#'   \item There are six random effects that are specific to modality A
+#'     \itemize{
+#'       \item var_r.Aneg: [num] variance of random reader effect
+#'       \item var_c.Aneg: [num] variance of random case effect
+#'       \item var_rc.Aneg: [num] variance of random reader by case effect
+#'       \item var_r.Apos: [num] variance of random reader effect
+#'       \item var_c.Apos: [num] variance of random case effect
+#'       \item var_rc.Apos: [num] variance of randome reader by case effect
+#'   }
+#'   \item There are six random effects that are specific to modality B
+#'     \itemize{
+#'       \item var_r.Bneg: [num] variance of random reader effect
+#'       \item var_c.Bneg: [num] variance of random case effect
+#'       \item var_rc.Bneg: [num] variance of random reader by case effect
+#'       \item var_r.Bpos: [num] variance of random reader effect
+#'       \item var_c.Bpos: [num] variance of random case effect
+#'       \item var_rc.Bpos: [num] variance of randome reader by case effect
+#'   }
+#' }
+#' 
+# @examples 
+# # Extract one configuration
+# config <- roeMetzConfigs[1, ]
+# # Create an MRMC ROC data set
+# df.iMRMC <- sim.gRoeMetz(config)
+# # Analyze the MRMC ROC data set
+# result <- doIMRMC(df.iMRMC)
+NULL
+
